import matplotlib.pyplot as plt
import sys
import os

script_name, what = sys.argv
if what != "times" and what != "results":
    os.exit(-1)

def load_data(name):
    with open("tmp/{}.dat".format(name), "r") as f:
        xs = []
        ys = []
        rs = []
        for l in f.readlines():
            x,y,r = l.strip().split(",")
            xs.append(int(x))
            ys.append(int(y))
            try:
                rs.append(float(r))
            except:
                rs.append(0)
        if what == "times":
            plt.plot(xs, ys)
        else:
            plt.plot(xs, rs)


plt.figure()
load_data("number")
load_data("float")
load_data("big")
legend = plt.legend(['number', 'float','big'], title = "Legend")
plt.savefig("{}.png".format(what))



import sys
from pathlib import Path

path = Path("../bindings/python3/zenroom/")
sys.path.append(path.resolve())

from zenroom.zenroom import zenroom_exec, zencode_exec

broken_zencode = """Scenario coconut: 'coconut'
When I"""

broken_zenroom = f"""
ZEN:begin(0)

ZEN:parse([[
{broken_zencode}
]])

ZEN:run()
"""

# UNCOMMENT THIS TO SEE ZENroom 
# print("execute zenROOM")
# zenroom_exec(broken_zenroom)


print("execute zenCODE")
zencode_exec(broken_zencode)




"""Zenroom bindings for python 3.6+"""

import io
import json
import ctypes as ct
from dataclasses import dataclass, field

from zenroom._config import LIBZENROOM_LOC


_LIBZENROOM = ct.CDLL(str(LIBZENROOM_LOC))


@dataclass
class ZenResult():
    output: str = field()
    logs: str = field()

    def __post_init__(self):
        try:
            self.result = json.loads(self.output)
        except json.JSONDecodeError:
            self.result = None


def _char_p(x):
    return ct.c_char_p(None if x is None else x.encode())


def _apply_call(call, script, conf, keys, data):
    # 2MB
    stdout_len = 2 * 1024 * 1024
    stdout_buf = ct.create_string_buffer(stdout_len)
    # 64kB
    stderr_len = 64 * 1024
    stderr_buf = ct.create_string_buffer(stderr_len)
    call(
        _char_p(script),
        _char_p(conf),
        _char_p(keys),
        _char_p(data),
        stdout_buf,
        stdout_len,
        stderr_buf,
        stderr_len,
    )
    return ZenResult(
        stdout_buf.value.decode().strip(),
        stderr_buf.value.decode().strip(),
    )


def zenroom_exec(script, conf=None, keys=None, data=None):
    return _apply_call(_LIBZENROOM.zenroom_exec_tobuf, script, conf, keys, data)


def zencode_exec(script, conf=None, keys=None, data=None):
    return _apply_call(_LIBZENROOM.zencode_exec_tobuf, script, conf, keys, data)
